package Local::TreePad;

# Purpose:
#	Read XML file output by TreePad.
#
# Note:
#	tabs = 4 spaces || die.

use base qw/XML::SAX::Base/;
use strict;
use warnings;

use Carp;
use HTML::Template;
use XML::SAX::ParserFactory;

our $VERSION = '1.00';

# -----------------------------------------------

# Encapsulated class data.

{
	my(%_attr_data) =
	(	# Alphabetical order.
	);

	sub _default_for
	{
		my($self, $attr_name) = @_;

		$_attr_data{$attr_name};
	}

	sub _standard_keys
	{
		keys %_attr_data;
	}
}

# -----------------------------------------------

sub characters
{
	my($self, $characters)	= @_;
	$$self{_text}			.= $$characters{Data};

}	# End of characters.

# -----------------------------------------------

sub end_document
{
	my($self) = @_;

}	# End of end_document.

# -----------------------------------------------

sub end_element
{
	my($self, $element) = @_;
	$$self{_text}		=~ s/^\s+//;
	$$self{_text}		=~ s/\s+$//;

	# Process text.

	if ($$element{Name} eq 'node')
	{
		$$self{'_inside_node'} = 0;
	}

	# Reset.

	$$self{_text} = '';

}	# End of end_element.

# -----------------------------------------------

sub generate_tree
{
	my($self) = @_;

}	# End of generate_tree.

# -----------------------------------------------

sub new
{
	my($class, %arg)	= @_;
	my($self)			= bless({}, $class);

	for my $attr_name ($self -> _standard_keys() )
	{
		my($arg_name) = $attr_name =~ /^_(.*)/;

		if (exists($arg{$arg_name}) )
		{
			$$self{$attr_name} = $arg{$arg_name};
		}
		else
		{
			$$self{$attr_name} = $self -> _default_for($attr_name);
		}
	}

	$$self{'_current_title'}	= '';	# Current node's title.
	$$self{'_data'}				= {};	# Holds all data.
	$$self{'_inside_node'}		= 0;
	$$self{'_title'}			= [];	# All node titles.

	return $self;

}	# End of new.

# -----------------------------------------------

sub run
{
	my($self, $file_name)	= @_;
	my($parser)				= XML::SAX::ParserFactory -> parser(Handler => $self);

	print 'Start:  ', scalar localtime(), ". \n";
	print "XML file: $file_name. \n";

	$parser -> parse_uri($file_name);
	#$self -> generate_tree();

	print map{"$_\n"} @{$$self{'_title'} };

	print 'Finish: ', scalar localtime(), ". \n";

}	# End of run.

# -----------------------------------------------

sub start_document
{
	my($self) = @_;

}	# End of start_document.

# -----------------------------------------------

sub start_element
{
	my($self, $element)	= @_;
	$$self{_text}		= '';

	if ($$element{Name} eq 'treepad_xmp')
	{
	}
	elsif ($$element{Name} eq 'database')
	{
	}
	elsif ($$element{Name} eq 'node')
	{
		$$self{'_title'} = $$element{Attributes}{'{}title'}{Value};

		if ($$self{'_inside_node'})
		{
		}
		else
		{
			$$self{'_inside_node'} = 1;

			push @{$$self{'_title'} }, $$self{'_title'};
		}
	}

}	# End of start_element.

# -----------------------------------------------

1;

__END__

=head1 NAME

C<Local::TreePad> - Read XML output by TreePad

=head1 Author

C<Local::TreePad> was written by Ron Savage in 2006.

[ron@savage.net.au]

Home page: http://savage.net.au/index.html

=head1 Copyright

Australian copyright (c) 2006, Ron Savage. All rights reserved.

	All Programs of mine are 'OSI Certified Open Source Software';
	you can redistribute them and/or modify them under the terms of
	The Artistic License, a copy of which is available at:
	http://www.opensource.org/licenses/index.html

=cut
